@@ -85,18 +85,17 @@ pub fn derive_bench_config(input: TokenStream) -> TokenStream {
         }
 
         impl #name {
-            pub fn is_match(&self, filter: &shumai::__dep::regex::Regex) -> bool {
-                filter.is_match(&self.name)
+            pub fn load_with_filter(path: impl AsRef<std::path::Path>, filter: impl AsRef<str>) -> std::option::Option<std::vec::Vec<#name>> {
+                let configs = BenchRootConfig::load_config(path.as_ref()).#lower_name()?;
+
+                let regex_filter =
+                            shumai::__dep::regex::Regex::new(filter.as_ref()).expect("failed to parse the benchmark filter into regex expression!");
+                let configs: std::vec::Vec<_> = configs.into_iter().filter(|c| regex_filter.is_match(&c.name)).collect();
+                Some(configs)
             }
 
-            pub fn load() -> std::option::Option<std::vec::Vec<#name>>{
-                use super::BenchRootConfig;
-                BenchRootConfig::load().#lower_name()
-            }
-
-            pub fn from_config(path: &std::path::Path) -> std::option::Option<std::vec::Vec<#name>> {
-                use super::BenchRootConfig;
-                BenchRootConfig::load_config(path).#lower_name()
+            pub fn load(path: impl AsRef<std::path::Path>) -> std::option::Option<std::vec::Vec<#name>> {
+                #name::load_with_filter(path, ".*")
             }
         }
 
@@ -122,9 +121,8 @@ pub fn derive_bench_config(input: TokenStream) -> TokenStream {
 }
 
 #[proc_macro_attribute]
-pub fn bench_config(args: TokenStream, input: TokenStream) -> TokenStream {
+pub fn shumai_config(args: TokenStream, input: TokenStream) -> TokenStream {
     assert!(args.is_empty());
-    let mut out = input.clone();
     let ty: syn::Item = syn::parse_macro_input!(input as syn::Item);
 
     let mut all_configs = Vec::new();
@@ -134,82 +132,71 @@ pub fn bench_config(args: TokenStream, input: TokenStream) -> TokenStream {
     } else {
         panic!("config attribute must be applied to mod");
     };
+
     let mod_items = item_mod.content.expect("mod can't be empty").1;
-    for item in mod_items {
+    for item in mod_items.iter() {
         if let syn::Item::Struct(conf_s) = item {
-            all_configs.push(conf_s.ident);
+            all_configs.push(conf_s);
         }
     }
+
     let mod_name = item_mod.ident;
 
     let root_fields = all_configs.iter().map(|f| {
-        let matrix_name = gen_matrix_name(f);
-        let lower_name = gen_lower_ident(f);
+        let matrix_name = gen_matrix_name(&f.ident);
+        let lower_name = gen_lower_ident(&f.ident);
         quote! {
             #lower_name: std::option::Option<std::vec::Vec<#matrix_name>>
         }
     });
 
     let field_functions = all_configs.iter().map(|f| {
-        let lower_name = gen_lower_ident(f);
+        let ident = &f.ident;
+        let lower_name = gen_lower_ident(ident);
         quote! {
-            pub fn #lower_name(&self) -> std::option::Option<std::vec::Vec<#f>>{
+            pub fn #lower_name(&self) -> std::option::Option<std::vec::Vec<#ident>>{
                 let mut configs = std::vec::Vec::new();
                 for b in self.#lower_name.as_ref()?.iter(){
                     configs.extend(b.unfold());
                 }
 
-                // println!("{:?}", configs);
-                // let args: std::vec::Vec<String> = std::env::args().collect();
-
-
-                // let default_filter = ".*".to_string();
-                // let filter_str = args.get(1).unwrap_or_else(|| &default_filter);
-                // let bench_filter =
-                //    shumai::__dep::regex::Regex::new(&filter_str).expect("failed to parse the benchmark filter into regex expression!");
-
-                // let configs: std::vec::Vec<_> = configs.into_iter().filter(|c| c.is_match(&bench_filter)).collect();
-
                 Some(configs)
             }
         }
     });
 
-    let field_import = all_configs.iter().map(|f| {
-        let matrix_name = gen_matrix_name(f);
+    let all_config_derived = all_configs.iter().map(|s| {
         quote! {
-            use self::#mod_name::{#matrix_name, #f};
+            #[derive(shumai_config_impl::ShumaiConfig, shumai::__dep::serde::Serialize, shumai::__dep::serde::Deserialize, Clone, Debug)]
+            #s
         }
     });
 
     let root_config = quote! {
 
-        #(#field_import)*
+        mod #mod_name {
 
-        #[derive(shumai::__dep::serde::Deserialize, Debug)]
-        struct BenchRootConfig {
-            #(#root_fields,)*
-        }
+            #(#all_config_derived)*
 
-        impl BenchRootConfig {
-            fn load_config(path: &std::path::Path)-> Self {
-                let contents = std::fs::read_to_string(path).unwrap();
-                let configs: BenchRootConfig =
-                    shumai::__dep::toml::from_str(&contents).expect("Unable to parse the toml file");
-                configs
+            #[derive(shumai::__dep::serde::Deserialize, Debug)]
+            struct BenchRootConfig {
+                #(#root_fields,)*
             }
 
-            fn load() -> Self {
-                BenchRootConfig::load_config(std::path::Path::new("benchmark.toml"))
-            }
+            impl BenchRootConfig {
+                fn load_config(path: &std::path::Path)-> Self {
+                    let contents = std::fs::read_to_string(path).unwrap();
+                    let configs: BenchRootConfig =
+                        shumai::__dep::toml::from_str(&contents).expect("Unable to parse the toml file");
+                    configs
+                }
 
-            #(#field_functions)*
+                #(#field_functions)*
+            }
         }
     };
 
-    out.extend(TokenStream::from(root_config));
-
-    out
+    root_config.into()
 }
 
 fn gen_matrix_name(name: &syn::Ident) -> syn::Ident {
